@@ -493,7 +493,7 @@ class PosixPlatformController(PlatformController):
         @param script_file: The path to the Python script file that was executed if it can be determined.  If it cannot
             then this will be None and script_binary will be supplied.
         @param script_binary:  The binary that is being executed.  This is only supplied if script_file is None.
-            On some systems, such as Windows running a script frozen by py2exe, the script is embedded in an actual
+            On some systems, such as Windows running a script frozen by PyInstaller, the script is embedded in an actual
             executable.
         @param script_arguments: The arguments passed in on the command line that need to be used for the new
             command line.
@@ -674,6 +674,7 @@ class PosixPlatformController(PlatformController):
         # On TERM we terminate the process, in USR1 we write a status file and on INT we terminate
         # the process when running in foreground (non-fork) mode
         # scalyr-agent-2 status -v uses SIGUSR1 underneath
+        # scalyr-agent-2 status -H uses SIGUSR2 underneath
         original_term = signal.signal(signal.SIGTERM, handle_terminate)
         original_interrupt = signal.signal(signal.SIGINT, handle_interrupt)
         original_usr1 = signal.signal(signal.SIGUSR1, handle_sigusr1)
@@ -750,7 +751,7 @@ class PosixPlatformController(PlatformController):
         """Invoked by a process that is not the agent to request the current agent dump the current detail
         status to the status file.
 
-        This is used to implement the 'scalyr-agent-2 status -v' feature.
+        This is used to implement the 'scalyr-agent-2 status -v' and `-H` features.
 
         @return: If there is an error, an errno that describes the error.  errno.EPERM indicates the current does not
             have permission to request the status.  errno.ESRCH indicates the agent is not running.
@@ -781,7 +782,7 @@ class PosixPlatformController(PlatformController):
     def register_for_status_requests(self, handler):
         """Register a method to be invoked if this process is requested to report its status.
 
-        This is used to implement the 'scalyr-agent-2 status -v' feature.
+        This is used to implement the 'scalyr-agent-2 status -v' and `-H` features.
 
         This should only be invoked by the agent service once it has begun to run.
 
