@@ -172,7 +172,7 @@ class ScalyrAgentService(win32serviceutil.ServiceFramework):
     """Implements the Windows service interface and exports the Scalyr Agent as a service.
     """
 
-    # The following fields must be present for py2exe to detect this as a service implementation.
+    # The following fields must be present for PyInstaller to detect this as a service implementation.
     _svc_name_ = _SCALYR_AGENT_SERVICE_
     _svc_display_name_ = _SCALYR_AGENT_SERVICE_DISPLAY_NAME_
 
@@ -411,7 +411,7 @@ class WindowsPlatformController(PlatformController):
         @param script_file: The path to the Python script file that was executed if it can be determined.  If it cannot
             then this will be None and script_binary will be supplied.
         @param script_binary:  The binary that is being executed.  This is only supplied if script_file is None.
-            On some systems, such as Windows running a script frozen by py2exe, the script is embedded in an actual
+            On some systems, such as Windows running a script frozen by PyInstaller, the script is embedded in an actual
             executable.
         @param script_arguments: The arguments passed in on the command line that need to be used for the new
             command line.
@@ -651,7 +651,7 @@ class WindowsPlatformController(PlatformController):
         """Invoked by a process that is not the agent to request the current agent dump the current detail
         status to the status file.
 
-        This is used to implement the 'scalyr-agent-2 status -v' feature.
+        This is used to implement the 'scalyr-agent-2 status -v' and `-H` features.
 
         @return: If there is an error, an errno that describes the error.  errno.EPERM indicates the current does not
             have permission to request the status.  errno.ESRCH indicates the agent is not running.
